@@ -1,18 +1,28 @@
 """
 Module listing all public method from the core_devoops modules
 """
+from core_devoops.app_activity import AppActivity
+from core_devoops.app_activity import dash_monitor
+from core_devoops.app_activity import fastapi_monitor
+from core_devoops.app_activity import get_method
+from core_devoops.app_activity import get_recent_activities
 from core_devoops.app_rights import AppRight
 from core_devoops.app_user import AppUser
+from core_devoops.app_user import select_user
 from core_devoops.app_user import upsert_app_users
 from core_devoops.auth_configuration import AUTH
-from core_devoops.authentification import attempt_to_log
-from core_devoops.authentification import get_app_services
-from core_devoops.authentification import get_current_user
-from core_devoops.authentification import get_user
-from core_devoops.authentification import is_admin_user
-from core_devoops.authentification import JwtAuth
-from core_devoops.authentification import SCHEME
-from core_devoops.authentification import Token
+from core_devoops.authentication import attempt_to_log
+from core_devoops.authentication import get_access_token
+from core_devoops.authentication import get_app_services
+from core_devoops.authentication import get_current_user
+from core_devoops.authentication import get_user
+from core_devoops.authentication import is_admin_user
+from core_devoops.authentication import is_authorized_user
+from core_devoops.authentication import is_monitoring_user
+from core_devoops.authentication import JwtAuth
+from core_devoops.authentication import SCHEME
+from core_devoops.authentication import Token
+from core_devoops.check_dependencies import check_dependencies
 from core_devoops.check_dependencies import compute_dependencies
 from core_devoops.custom_equal import custom_equal
 from core_devoops.db_connection import create_db_and_tables
@@ -63,5 +73,7 @@ __all__ = [
     'SafeTestCase', 'SimpleReturn', 'safe_clt', 'stringify', 'boolify', 'get_user', 'floatify',
     'delete_table', 'SCHEME', 'DB_URL', 'pd_equals', 'jsonify_series', 'upsert_app_users', 'intify',
     'enum_converter', 'ServerSideFilter', 'get_rows', 'count_rows', 'ServerSideField', 'get_raw_df',
-    'generic_insertion', 'custom_equal'
+    'generic_insertion', 'custom_equal', 'is_authorized_user', 'get_method', 'AppActivity',
+    'fastapi_monitor', 'dash_monitor', 'is_monitoring_user', 'get_recent_activities', 'select_user',
+    'get_access_token'
 ]
